Bootstrap5Components.Resource protocol (bootstrap5components v0.5.2)
View SourceA protocol to help represent resources in web applications
using the components defined by Bootstrap5Components.
Summary
Functions
Render resource as HTML.
Render resource as plain text.
Path for the resource in a given web application.
Types
@type t() :: term()
All the types that implement this protocol.